<?php
/* Set up the option tree plugin.
 ----------------------------------------------------------- */
if ( ! function_exists( 'ot_get_option' ) ) {
  function ot_get_option( $option_id, $default = '' ) {
    /* get the saved options */
    $options = get_option( 'option_tree' );
    /* look for the saved value */
    if ( isset( $options[$option_id] ) && '' != $options[$option_id] ) {
      return ot_wpml_filter( $options, $option_id );
    }
    return $default;
  }
}

if ( ! function_exists( 'ot_wpml_filter' ) ) {
  function ot_wpml_filter( $options, $option_id ) {
    // Return translated strings using WMPL
    if ( function_exists('icl_t') ) {
      $settings = get_option( 'option_tree_settings' );
      if ( isset( $settings['settings'] ) ) {
        foreach( $settings['settings'] as $setting ) {
          // List Item & Slider
          if ( $option_id == $setting['id'] && in_array( $setting['type'], array( 'list-item', 'slider' ) ) ) {
            foreach( $options[$option_id] as $key => $value ) {
              foreach( $value as $ckey => $cvalue ) {
                $id = $option_id . '_' . $ckey . '_' . $key;
                $_string = icl_t( 'Theme Options', $id, $cvalue );
                if ( ! empty( $_string ) ) {
                  $options[$option_id][$key][$ckey] = $_string;
                }
              }
            }
          // All other acceptable option types
          } else if ( $option_id == $setting['id'] && in_array( $setting['type'], apply_filters( 'ot_wpml_option_types', array( 'text', 'textarea', 'textarea-simple' ) ) ) ) {
            $_string = icl_t( 'Theme Options', $option_id, $options[$option_id] );
            if ( ! empty( $_string ) ) {
              $options[$option_id] = $_string;
            }
          }
        }
      }
    }
    return $options[$option_id];
  }
}
/* Set up the content width value based on the theme's design.
 ----------------------------------------------------------- */

if ( ! isset( $content_width ) ) {
  $content_width = 960;
}

/* HAMMER setup.
 ----------------------------------------------------------- */

if ( ! function_exists( 'BB_setup' ) ) :
    function BB_setup() {


         /*
       * Let WordPress manage the document title.
       * By adding theme support, we declare that this theme does not use a
       * hard-coded <title> tag in the document head, and expect WordPress to
       * provide it for us.
       */
      add_theme_support( 'title-tag' );

     /* Add RSS feed links to <head> for posts and comments.*/
     add_theme_support( 'automatic-feed-links' );

     /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
      'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

     // This theme uses wp_nav_menu() in 3 locations.
    register_nav_menus( array(
      'top'   => __( ' Top  menu', 'BB' ),
      'mega-menu'   => __( ' Mega  menu', 'BB' ),
    ) );

    // This theme allows users to set a custom background.
    $custombg = array('default-color' => '#f9f9f9',);
    add_theme_support( 'custom-background', $custombg );

    // This theme allows users to set a custom Header.
    $args = array(
      'width'         => 1170,
      'height'        => 60,
      'default-image' => get_template_directory_uri() . '/images/header.jpg',
    );
    add_theme_support( 'custom-header', $args );


    /*
     * Enable support for Post Formats.
     * See http://codex.wordpress.org/Post_Formats
     */
    add_theme_support( 'post-formats', array( 'video', 'audio' , 'gallery' ) );

    add_theme_support( 'post-thumbnails' );
    // Enable support for Post Thumbnails, and declare All sizes.
      add_image_size( 'BB-p', 800, 900 , true );
      add_image_size( 'BB-f', 1400, 650, true );
      add_image_size( 'BB-3', 380, 300, true );
      add_image_size( 'BB-2', 600, 700,true );
      add_image_size( 'BB-list' ,700,600,true );
      add_image_size( 'BB-m2' , 480, 710,true );
      add_image_size( 'BB-cor' , 1400, 550,true );
      add_image_size( 'BB-live', 180, 180, true );


   }
  endif; // BB_setup
add_action( 'after_setup_theme', 'BB_setup' );

// Use shortcodes in text widgets.
add_filter( 'widget_text', 'do_shortcode' );

add_filter( 'the_content', 'do_shortcode', 11 ); // From shortcodes.php

add_filter( 'searchwp_live_search_hijack_get_search_form', '__return_false' );

/*-----------------------------------------------------------
  Add Content & excerpt Limit
-------------------------------------------------------------*/
function excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
  return $excerpt;
}

/*===========================================*
 * Register three  widget areas.
 *===========================================*/
 function BB_widgets_init() {

 /*Homepage Sidebar
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Primary Sidebar', 'BB' ),
    'id'            => 'sidebar-home',
    'description'   => __( 'Main sidebar that appears on the Right Only On (Homepage, Archive, Tag, Search).', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="page-bulider-header"><h3 class="head">',
    'after_title'   => '</h3></div>',
  ) );
  /*Category Sidebar
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Category Sidebar', 'BB' ),
    'id'            => 'sidebar-category',
    'description'   => __( 'Main sidebar that appears on the  Category.', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget  %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="page-bulider-header"><h3 class="head">',
    'after_title'   => '</h3></div>',
  ) );
  /*Section (B)
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Section (B) Page Builder Sidebar', 'BB' ),
    'id'            => 'sidebar-b',
    'description'   => __( 'Main sidebar that appears on the  Section (B) On Page Builder.', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget  %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="page-bulider-header"><h3 class="head"><span></span>',
    'after_title'   => '</h3></div>',
  ) );
  /*Section (D)
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Section (D) Page Builder Sidebar', 'BB' ),
    'id'            => 'sidebar-d',
    'description'   => __( 'Main sidebar that appears on the  Section (D) On Page Builder.', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="page-bulider-header"><h3 class="head"><span></span>',
    'after_title'   => '</h3></div>',
  ) );
  /*Post Sidebar
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Post Sidebar', 'BB' ),
    'id'            => 'sidebar-post',
    'description'   => __( 'Main sidebar that appears on the  Post.', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget %2$s">',
    'after_widget'  => '</aside>',
   'before_title'  => '<div class="page-bulider-header"><h3 class="head"><span></span>',
    'after_title'   => '</h3></div>',
  ) );
    /*Post Sidebar
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Post Sidebar-2', 'BB' ),
    'id'            => 'sidebar-post-2',
    'description'   => __( 'Main sidebar that appears on the  Post whith 2sidebar(left).', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget %2$s">',
    'after_widget'  => '</aside>',
   'before_title'  => '<div class="page-bulider-header"><h3 class="head"><span></span>',
    'after_title'   => '</h3></div>',
  ) );
 
  /*Sidebar For Home Page video right
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Single Page video Sidebar small', 'BB' ),
    'id'            => 'sidebar-video-2',
    'description'   => __( 'Sidebar For Single Page video small', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget  %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="wid-nc-video"><h3 class="head-nc">',
    'after_title'   => '</h3></div>',
  ) );
  /*Footer Sidebar 1
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Footer Sidebar 1', 'BB' ),
    'id'            => 'footer-1',
    'description'   => __( 'Additional sidebar that appears on the Footer .', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="widgets %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="footer-widget-header"><h3 class="head-footer">',
    'after_title'   => '</h3></div>',
  ) );
  /*Footer Sidebar 2
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Footer Sidebar 2', 'BB' ),
    'id'            => 'footer-2',
    'description'   => __( 'Additional sidebar that appears on the Footer .', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="widgets %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="footer-widget-header"><h3 class="head-footer">',
    'after_title'   => '</h3></div>',
  ) );
  /*Footer Sidebar 3
 -----------------------------*/
  register_sidebar( array(
    'name'          => __( 'Footer Sidebar 3', 'BB' ),
    'id'            => 'footer-3',
    'description'   => __( 'Additional sidebar that appears on the Footer .', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="widgets %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="footer-widget-header"><h3 class="head-footer">',
    'after_title'   => '</h3></div>',
  ) );
  /*Woocommerce Sidebar
 -----------------------------*/
   if ( class_exists( 'Woocommerce' ) ) {
     register_sidebar( array(
    'name'          => __( 'Woocommerce Sidebar', 'BB' ),
    'id'            => 'woo-shop',
    'description'   => __( 'Additional sidebar that appears on the right of Woocommerce.', 'BB' ),
    'before_widget' => '<aside id="%1$s" class="home-widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<div class="page-bulider-header"><h3 class="head"><span></span>',
    'after_title'   => '</h3></div>',
  ) );
    
   }

}
add_action( 'widgets_init', 'BB_widgets_init' );


/*
 custom walker Menu /
*/

class BB_Class_Walker extends Walker_Nav_Menu {
  function start_lvl(&$output, $depth = 0, $args= array()) {
    $indent = str_repeat("\t", $depth);
    $output .= "\n$indent<ul class=\"dl-submenu\">\n";
  }
}



if ( ! function_exists( 'BB_posted_on' ) ) :
/**
 * Print HTML with meta information for the current post-date/time and author.
 */
function BB_posted_on() {
  while ( have_posts() ) : the_post();

  // Set up and print post meta information.
    printf(
     '<span class="entry-date">' . __( 'IN', 'BB' ) . '
      <a href="%1$s" rel="bookmark">
      <time class="entry-date updated" datetime="%2$s">%3$s</time>
      </a></span> <span class="byline">
      <span class="author vcard">' . __( 'BY', 'BB' ) . '
      <a class="url fn n" href="%4$s" rel="author">%5$s</a>
      </span>
      </span>',
    esc_url( get_permalink() ),
    esc_attr( get_the_date( 'c' ) ),
    esc_html( get_the_date() ),
    esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
    get_the_author()
  );
  endwhile;
}
endif;


/*Usage - the_post_thumbnail_caption();*/
function the_post_thumbnail_caption() {
  
  global $post;
  $thumbnail_id    = get_post_thumbnail_id(get_the_id());
  $thumbnail_image = get_posts(array('p' => $thumbnail_id, 'post_type' => 'attachment'));
  if(get_post(get_post_thumbnail_id())->post_excerpt) {
  if ($thumbnail_image && isset($thumbnail_image[0])) {
    echo '<span class="post-cap"><i class="fa fa-camera"></i>&nbsp;&nbsp;'.$thumbnail_image[0]->post_excerpt.'</span>';
  }
}
}
/**/

/*-----------------------------------------------------------------------------------*/
# Add "dark-skin" for body
/*-----------------------------------------------------------------------------------*/
add_filter('body_class','BB_body_class_dark');
function BB_body_class_dark($classes)
{
  $dark_skin = ot_get_option('bb_dark_skin'); if ($dark_skin == "on")
    $classes[] = 'dark-skin';
  return $classes;

}

/**
 * Remove rel attribute from the category list
 */
function remove_category_list_rel( $output ) {
    return str_replace( 'rel="category tag"', '', $output );
}
add_filter( 'wp_list_categories', 'remove_category_list_rel' );
add_filter( 'the_category', 'remove_category_list_rel' );


/**
 * Theme localization
 */
load_theme_textdomain( 'BB', get_template_directory() . '/languages' );
$locale = get_locale();
$locale_file = get_template_directory() . "/languages/$locale.php";
if ( is_readable($locale_file) ) require_once($locale_file);



function getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0 View";
    }
    return $count.'';
}
function setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// Remove issues with prefetching adding extra views
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0); 


/*********************
LIMITED TAGCLOUD WIDGET
*********************/
if ( ! function_exists( 'bb_tag_cloud_widget' ) ) {
    function bb_tag_cloud_widget($args) {
        $args['number'] = 20;
        return $args;
    }
}
add_filter( 'widget_tag_cloud_args', 'bb_tag_cloud_widget' );

/*
Wrap Post count in a span
 ==========================================*/
add_filter('wp_list_categories', 'bb_cat_count_span');
function bb_cat_count_span($links) {

  $links = str_replace('</a> (', '</a> <span class="cat-count">', $links);
  $links = str_replace(')', '</span>', $links);
  return $links;
}

// Search_Filter
// ----------------------------------
function bb_Search_Filter($query) {
  if( $query->is_search ){
      $post_types = get_post_types(array( 'public' => true, 'exclude_from_search' => false ));
      unset($post_types['page']);
      unset($post_types['product']);
      $query->set('post_type', $post_types );  
  }
  return $query;
}
add_filter('pre_get_posts','bb_Search_Filter');





if ( !function_exists( 'pagination' ) ) {

function pagination($pages = '', $range = 4)

{

     $showitems = ($range * 2)+1;



     global $paged;

     if(empty($paged)) $paged = 1;



     if($pages == '')

     {

         global $wp_query;

         $pages = $wp_query->max_num_pages;

         if(!$pages)

         {

             $pages = 1;

         }

     }



     if(1 != $pages)

     {

         echo "<div class=\"pagination\"><span>Page ".$paged." of ".$pages."</span>";

         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>&laquo; First</a>";

         if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>&lsaquo; Previous</a>";



         for ($i=1; $i <= $pages; $i++)

         {

             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))

             {

                 echo ($paged == $i)? "<span class=\"current\">".$i."</span>":"<a href='".get_pagenum_link($i)."' class=\"inactive\">".$i."</a>";

             }

         }



         if ($paged < $pages && $showitems < $pages) echo "<a href=\"".get_pagenum_link($paged + 1)."\">Next &rsaquo;</a>";

         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>Last &raquo;</a>";

         echo "</div>\n";

     }

}

}


/*-----------------------------------------------------------
  Add/Remove User Contact Info
-------------------------------------------------------------*/
    function new_contactmethods( $contactmethods ) {
    unset($contactmethods['yim']); // Remove YIM
    unset($contactmethods['aim']); // Remove AIM
    unset($contactmethods['jabber']); // Remove Jabber
    return $contactmethods;
    }
      add_filter('user_contactmethods','new_contactmethods',10,1);
      add_action('show_user_profile', 'wpsplash_extraProfileFields');
      add_action('edit_user_profile', 'wpsplash_extraProfileFields');
      add_action('personal_options_update', 'wpsplash_saveExtraProfileFields');
      add_action('edit_user_profile_update', 'wpsplash_saveExtraProfileFields');

    function wpsplash_saveExtraProfileFields($userID) {
    
    if (!current_user_can('edit_user', $userID)) {
    return true;
    }

      update_user_meta($userID, 'twitter', $_POST['twitter']);
      update_user_meta($userID, 'facebook', $_POST['facebook']);
      update_user_meta($userID, 'googleplus', $_POST['googleplus']);
      update_user_meta($userID, 'flickr', $_POST['flickr']);
      update_user_meta($userID, 'linkedin', $_POST['linkedin']);
      update_user_meta($userID, 'pinterest', $_POST['pinterest']);
}

function wpsplash_extraProfileFields($user)
{
?>
  <h3>
  <span class="dashicons dashicons-share"></span>
  <strong style="color:red;"><?php _e("News Code User Contact Info","BB" ); ?></strong>
  </h3>

  <table class='form-table'>
    <tr>
      <th><span class="dashicons dashicons-twitter"></span> <label for='twitter'>Twitter</label></th>
      <td>
        <input type='text' name='twitter' id='twitter' value='<?php echo esc_attr(get_the_author_meta('twitter', $user->ID)); ?>' class='regular-text' />
        <br />
        <span class='description'>Twitter Username. Eg. http://www.twitter.com/<strong>username</strong></span>
      </td>
    </tr>
    <tr>
      <th><span class="dashicons dashicons-facebook"></span> <label for='facebook'>Facebook</label></th>
      <td>
        <input type='text' name='facebook' id='facebook' value='<?php echo esc_attr(get_the_author_meta('facebook', $user->ID)); ?>' class='regular-text' />
        <br />
        <span class='description'>Facebook Username or Alias. Eg. http://www.facebook.com/<strong>username</strong></span>
      </td>
    </tr>
    <tr>
      <th><span class="dashicons dashicons-googleplus"></span> <label for='googleplus'>Google Plus</label></th>
      <td>
        <input type='text' name='googleplus' id='googleplus' value='<?php echo esc_attr(get_the_author_meta('googleplus', $user->ID)); ?>' class='regular-text' />
        <br />
        <span class='description'>Google Plus Username or Alias. Eg. http://plus.google.com/<strong>username</strong></span>
      </td>
    </tr>
    <tr>
      <th><span class="dashicons dashicons-camera"></span> <label for='flickr'>Flickr</label></th>
      <td>
        <input type='text' name='flickr' id='flickr' value='<?php echo esc_attr(get_the_author_meta('flickr', $user->ID)); ?>' class='regular-text' />
        <br />
        <span class='description'>Flickr Username or Alias. Eg. http://www.flickr.com/photos/<strong>username</strong></span>
      </td>
    </tr>
    <tr>
      <th><span class="dashicons dashicons-networking"></span> <label for='linkedin'>LinkedIn</label></th>
      <td>
        <input type='text' name='linkedin' id='linkedin' value='<?php echo esc_attr(get_the_author_meta('linkedin', $user->ID)); ?>' class='regular-text' />
        <br />
        <span class='description'>LinkedIn Username or Alias. Eg. http://www.linkedin.com/<strong>username</strong></span>
      </td>
    </tr>
    <tr>
      <th><span class="dashicons dashicons-networking"></span> <label for='pinterest'>Pinterest</label></th>
      <td>
        <input type='text' name='pinterest' id='pinterest' value='<?php echo esc_attr(get_the_author_meta('pinterest', $user->ID)); ?>' class='regular-text' />
        <br />
        <span class='description'>Pinterest Username or Alias. Eg. http://pinterest.com/<strong>username</strong></span>
      </td>
    </tr>
  </table>
<?php } 
