<?php 
/*
Declare WooCommerce support in third party theme
----------------------------------------------------------*/
add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

 if ( ! function_exists( 'bb_woocommerce_return_false' ) ) {
        function bb_woocommerce_return_false() {
            return false;
        }
    }

    add_filter( 'woocommerce_show_page_title', 'bb_woocommerce_return_false' );
/*
 Ensure cart contents update when products are added to the cart via AJAX (place the following in functions.php)
---------------------------------------------------------------------------------------------*/
add_filter('add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment');
 
function woocommerce_header_add_to_cart_fragment( $fragments ) {
  global $woocommerce;
  ob_start();
  ?>
  <a class="cart-contents" href="<?php echo $woocommerce->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'woothemes'); ?>"><i class="fa fa-shopping-cart"></i><span><?php echo sprintf(_n('%d', '%d', $woocommerce->cart->cart_contents_count, 'woothemes'), $woocommerce->cart->cart_contents_count);?></span></a>
  <?php
  $fragments['a.cart-contents'] = ob_get_clean();
  return $fragments;
}

/*
Change number of thumbnails per row in product galleries
-----------------------------------------------------------*/
add_filter ( 'woocommerce_product_thumbnails_columns', 'bb_thumb_cols' );
if ( ! function_exists( 'bb_thumb_cols' ) ) {
 function bb_thumb_cols() {
     return 2; // .last class applied to every 4th thumbnail
   }
}
/*
Change number of thumbnails per row in loop shop
-----------------------------------------------------------------------*/ 
 if ( ! function_exists( 'bb_row_number' ) ) {
        function bb_row_number() {
        	$bb_row = 4;
        	return $bb_row;
    }
}
add_filter('loop_shop_columns', 'bb_row_number');

/*
Disable the default stylesheet
-----------------------------------------------------------------------*/
add_filter( 'woocommerce_enqueue_styles', '__return_false' );

function wp_enqueue_woocommerce_style(){
    wp_register_style( 'woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'woocommerce' );
	}
}
add_action( 'wp_enqueue_scripts', 'wp_enqueue_woocommerce_style' );

/*

---------------------------------------------------------------------*/
/**
 * Hook in on activation
 */
 
/**
 * Define image sizes
 */
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' )
	add_action( 'init', 'tie_woocommerce_image_dimensions', 1 );

function tie_woocommerce_image_dimensions() {
  	$catalog = array(
		'width' 	=> '400',	// px
		'height'	=> '400',	// px
		'crop'		=> 1 		// true
	);
 
	$single = array(
		'width' 	=> '600',	// px
		'height'	=> '600',	// px
		'crop'		=> 1 		// true
	);
 
	$thumbnail = array(
		'width' 	=> '600',	// px
		'height'	=> '600',	// px
		'crop'		=> 1 		// false
	);
 
	// Image sizes
	update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
	update_option( 'shop_single_image_size', $single ); 		// Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs
}

/*
* WooCommerce Extra Feature
 * --------------------------
 *
 * Change number of related products on product page
 * Set your own value for 'posts_per_page'
---------------------------------------------------*/
function woo_related_products_limit() {
  global $product;
	
	$args['posts_per_page'] = 6;
	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'bb_related_products_args' );
  function bb_related_products_args( $args ) {
 
	$args['posts_per_page'] = 2; // 4 related products
	$args['columns'] = 2; // arranged in 2 columns
	return $args;
}


//remove upsell products
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15); 

//remove single product thumbnails 
remove_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_thumbnails', 20 );